#
# fishing.R, 12 Jan 25
#
# Data from:
# Rediscovery Datasets: Connecting Duplicate Reports
# Mefta Sadat , Ayse Basar Bener , Andriy V. Miranskyy

library("colorspace")
library("plyr")


par(bty="l")
par(las=1)
par(pch="+")
pal_col=rainbow(2)



# Show a days line for a given base fault id
plot_id=function(id_val, col_str)
{
top_dup=subset(k_dates, id == id_val)

# lines(top_dup$days)
points(top_dup$days, col=col_str)
}


# Plot day lines for a range of fault ids, based on
# their number of duplicates
plot_range=function(base)
{
plot(0.1, type="n", log="y",
	xlim=c(1, dups$freq[base]), ylim=c(10, 1e3),
	xlab="Fault id", ylab="Days since first report")

# plot_id(291262)
# plot_id(342763)

pal_col=rainbow(10)

for (i in 1:10)
   plot_id(dups$x[base+i], pal_col[i])
}


# Return mean/sd of day interval between duplicate reports of the same fault
mean_rep_time=function(df)
{
# Need a minimum sample size
if (nrow(df) < 20)
   return(NULL)
# Remove cases where many same day reports because fault is so prevalent
if (nrow(df) > 100)
   return(NULL)

# add in base date
dates=c(df$date.x[1], df$date.y)
dates=dates[order(dates, decreasing=FALSE)]
mean_sd=data.frame(mean=mean(as.numeric(diff(dates))),
			sd=sd(as.numeric(diff(dates))))

return(mean_sd)
}


dup_kde=read.csv("kde.relations.csv")
kde=read.csv("kde.csv")

kde$date=as.Date(kde$opendate, format="%Y-%m-%d")

id_date=data.frame(id=kde$id, date=kde$date)

start_date=ad.Date("1999-01-01", format="%Y-%m-%d")

# This seems the simplest way to add the needed dates
k_dates=merge(dup_kde, id_date, by="id")
k_dates=merge(k_dates, id_date, by.x="dup", by.y="id", all.x=TRUE)

k_dates$days=as.numeric(k_dates$date.y-k_dates$date.x)


dups=count(dup_kde)
dups=dups[order(dups$freq, decreasing=TRUE), ]

plot(dups$freq, log="xy")


plot_range(25) # Used in blog article

dev.copy(dev=png, file="dup_rep_day-25.png")
dev.off()

plot_range(30)


rep_time=ddply(k_dates, .(id), mean_rep_time)

# nrow(subset(rep_time, !is.na(mean)))
# 392 for kde

# mean time between reports for each fault
plot(sort(rep_time$mean), col="salmon",
	xlab="Fault id", ylab="Mean duplicate report time (days)")

dev.copy(dev=png, file="mean_dup_rep_interval.png")
dev.off()

